pub struct IpData { /* private fields */ }Expand description
This struct helps us ensure that a given IP isn’t making too many accounts this could be expanded upon as a broader rate limit, for now we’re just going to apply the pattern where it’s needed (new-account).